@@ -20,6 +20,7 @@ from django.dispatch import receiver
 from django.conf import settings
 
 from . import defaults
+from .utils import get_storage
 
 
 class MailerMessageManager(models.Manager):
@@ -126,7 +127,7 @@ class MailerMessage(models.Model):
 
 @python_2_unicode_compatible
 class Attachment(models.Model):
-    file_attachment = models.FileField(upload_to='mail-queue/attachments', blank=True, null=True)
+    file_attachment = models.FileField(storage=get_storage(), upload_to='mail-queue/attachments', blank=True, null=True)
     email = models.ForeignKey(MailerMessage, blank=True, null=True)
 
     class Meta:
